==> openbao-2.0.0.tar.gz: openbao-2.0.0/sdk/helper/logging/logging_test.go <==
// Copyright (c) HashiCorp, Inc.
// SPDX-License-Identifier: MPL-2.0

package logging

import (
	"errors"
	"os"
	"reflect"
	"testing"

	"github.com/openbao/openbao/api"
)

func Test_ParseLogFormat(t *testing.T) {
	type testData struct {
		format      string
		expected    LogFormat
		expectedErr error
	}

	tests := []testData{
		{format: "", expected: UnspecifiedFormat, expectedErr: nil},
		{format: " ", expected: UnspecifiedFormat, expectedErr: nil},
		{format: "standard", expected: StandardFormat, expectedErr: nil},
		{format: "STANDARD", expected: StandardFormat, expectedErr: nil},
		{format: "json", expected: JSONFormat, expectedErr: nil},
		{format: " json ", expected: JSONFormat, expectedErr: nil},
		{format: "bogus", expected: UnspecifiedFormat, expectedErr: errors.New("unknown log format: bogus")},
	}

	for _, test := range tests {
		result, err := ParseLogFormat(test.format)
		if test.expected != result {
			t.Errorf("expected %s, got %s", test.expected, result)
		}
		if !reflect.DeepEqual(test.expectedErr, err) {
			t.Errorf("expected error %v, got %v", test.expectedErr, err)
		}
	}
}

func Test_ParseEnv_BAO_LOG_FORMAT(t *testing.T) {
	oldVLF := api.ReadBaoVariable("BAO_LOG_FORMAT")
	defer os.Setenv("BAO_LOG_FORMAT", oldVLF)

	testParseEnvLogFormat(t, "BAO_LOG_FORMAT")
}

func testParseEnvLogFormat(t *testing.T, name string) {
	env := []string{
		"json", "vauLT_Json", "VAULT-JSON", "vaulTJSon",
		"standard", "STANDARD",
		"bogus",
	}

	formats := []LogFormat{
		JSONFormat, JSONFormat, JSONFormat, JSONFormat,
		StandardFormat, StandardFormat,
		UnspecifiedFormat,
	}

	for i, e := range env {
		os.Setenv(name, e)
		if lf := ParseEnvLogFormat(); formats[i] != lf {
			t.Errorf("expected %s, got %s", formats[i], lf)
		}
	}
}

==> openbao-2.2.1.tar.gz: openbao-2.2.1/sdk/helper/logging/logging_test.go <==
// Copyright (c) HashiCorp, Inc.
// SPDX-License-Identifier: MPL-2.0

package logging

import (
	"errors"
	"os"
	"reflect"
	"testing"

	"github.com/openbao/openbao/api/v2"
)

func Test_ParseLogFormat(t *testing.T) {
	type testData struct {
		format      string
		expected    LogFormat
		expectedErr error
	}

	tests := []testData{
		{format: "", expected: UnspecifiedFormat, expectedErr: nil},
		{format: " ", expected: UnspecifiedFormat, expectedErr: nil},
		{format: "standard", expected: StandardFormat, expectedErr: nil},
		{format: "STANDARD", expected: StandardFormat, expectedErr: nil},
		{format: "json", expected: JSONFormat, expectedErr: nil},
		{format: " json ", expected: JSONFormat, expectedErr: nil},
		{format: "bogus", expected: UnspecifiedFormat, expectedErr: errors.New("unknown log format: bogus")},
	}

	for _, test := range tests {
		result, err := ParseLogFormat(test.format)
		if test.expected != result {
			t.Errorf("expected %s, got %s", test.expected, result)
		}
		if !reflect.DeepEqual(test.expectedErr, err) {
			t.Errorf("expected error %v, got %v", test.expectedErr, err)
		}
	}
}

func Test_ParseEnv_BAO_LOG_FORMAT(t *testing.T) {
	oldVLF := api.ReadBaoVariable("BAO_LOG_FORMAT")
	defer os.Setenv("BAO_LOG_FORMAT", oldVLF)

	testParseEnvLogFormat(t, "BAO_LOG_FORMAT")
}

func testParseEnvLogFormat(t *testing.T, name string) {
	env := []string{
		"json", "vauLT_Json", "VAULT-JSON", "vaulTJSon",
		"standard", "STANDARD",
		"bogus",
	}

	formats := []LogFormat{
		JSONFormat, JSONFormat, JSONFormat, JSONFormat,
		StandardFormat, StandardFormat,
		UnspecifiedFormat,
	}

	for i, e := range env {
		os.Setenv(name, e)
		if lf := ParseEnvLogFormat(); formats[i] != lf {
			t.Errorf("expected %s, got %s", formats[i], lf)
		}
	}
}
